@@ -11,7 +11,7 @@ use Business::OnlinePayment::HTTPS;
 
 @ISA = qw(Business::OnlinePayment::HTTPS);
 $DEBUG = 0;
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 # mapping out all possible endpoints
 # but this version will only be building out "charge", "void", & "credit"
@@ -97,7 +97,7 @@ sub set_defaults {
     
     $self->build_subs(qw/
             platform tid appid
-            action reference_number cvv_response avs_response response_code
+            action reference_number cvv2_response avs_code response_code
             risk_score txn_amount txn_date
     /);
     
@@ -346,8 +346,8 @@ sub parse_response {
         warn "Response:\n".Dumper($response)."\n" if $DEBUG > 2;
         $self->result_code($response->{Status}); # 0 /1
         $self->response_code($response->{ResponseCode}); # see documentation for translation
-        $self->avs_response($response->{AvsResponse}); # Y / N
-        $self->cvv_response($response->{CvvResponse}); # P / F
+        $self->avs_code($response->{AvsResponse}); # Y / N
+        $self->cvv2_response($response->{CvvResponse}); # P / F
         $self->txn_date($response->{TransactionDate}); # MMDDhhmmss
         $self->txn_amount($response->{TransactionAmount} / 100); # 00000003500 / 100
         $self->reference_number($response->{ReferenceNumber});
